@@ -4,6 +4,8 @@
 
 from __future__ import absolute_import
 import six
+
+
 class PycommandsException(Exception):
     pass
 
@@ -16,23 +18,27 @@ class DoesNotExist(PycommandsException):
     pass
 
 
-class DataObjectDoesNotExist(PycommandsException):
+class DataObjectDoesNotExist(DoesNotExist):
     pass
 
 
-class CollectionDoesNotExist(PycommandsException):
+class CollectionDoesNotExist(DoesNotExist):
     pass
 
 
-class UserDoesNotExist(PycommandsException):
+class ZoneDoesNotExist(DoesNotExist):
     pass
 
 
-class UserGroupDoesNotExist(PycommandsException):
+class UserDoesNotExist(DoesNotExist):
     pass
 
 
-class ResourceDoesNotExist(PycommandsException):
+class UserGroupDoesNotExist(DoesNotExist):
+    pass
+
+
+class ResourceDoesNotExist(DoesNotExist):
     pass
 
 
@@ -64,8 +70,8 @@ class iRODSException(six.with_metaclass(iRODSExceptionMeta, Exception)):
     pass
 
 
-def get_exception_by_code(code):
-    return iRODSExceptionMeta.codes[code]()
+def get_exception_by_code(code, message=None):
+    return iRODSExceptionMeta.codes[code](message)
 
 
 class SystemException(iRODSException):
@@ -556,7 +562,7 @@ class USER_FILE_TOO_LARGE(UserInputException):
     code = -311000
 
 
-class OVERWITE_WITHOUT_FORCE_FLAG(UserInputException):
+class OVERWRITE_WITHOUT_FORCE_FLAG(UserInputException):
     code = -312000
 
 
@@ -1128,6 +1134,13 @@ class CAT_TABLE_ACCESS_DENIED(CatalogLibraryException):
     code = -851000
 
 
+class CAT_UNKNOWN_SPECIFIC_QUERY(CatalogLibraryException):
+    code = -853000
+
+class CAT_STATEMENT_TABLE_FULL(CatalogLibraryException):
+    code = -860000
+
+
 class RDSException(iRODSException):
     pass
 
@@ -1870,3 +1883,23 @@ class PHP_REQUEST_STARTUP_ERR(PHPException):
 
 class PHP_OPEN_SCRIPT_FILE_ERR(PHPException):
     code = -1602000
+
+
+class PAMException(iRODSException):
+    pass
+
+
+class PAM_AUTH_NOT_BUILT_INTO_CLIENT(PAMException):
+    code = -991000
+
+
+class PAM_AUTH_NOT_BUILT_INTO_SERVER(PAMException):
+    code = -992000
+
+
+class PAM_AUTH_PASSWORD_FAILED(PAMException):
+    code = -993000
+
+
+class PAM_AUTH_PASSWORD_INVALID_TTL(PAMException):
+    code = -994000
