@@ -1,6 +1,7 @@
 import struct
 import logging
 import socket
+import json
 import xml.etree.ElementTree as ET
 from irods.message.message import Message
 from irods.message.property import (BinaryProperty, StringProperty,
@@ -68,6 +69,10 @@ class iRODSMessage(object):
         self.bs = bs
         self.int_info = int_info
 
+    def get_json_encoded_struct (self):
+        Xml = ET.fromstring(self.msg.replace(b'\0',b''))
+        return json.loads(Xml.find('buf').text)
+
     @staticmethod
     def recv(sock):
         # rsp_header_size = sock.recv(4, socket.MSG_WAITALL)
@@ -188,7 +193,7 @@ class ClientServerNegotiation(Message):
 class StartupPack(Message):
     _name = 'StartupPack_PI'
 
-    def __init__(self, proxy_user, client_user):
+    def __init__(self, proxy_user, client_user, application_name = ''):
         super(StartupPack, self).__init__()
         if proxy_user and client_user:
             self.irodsProt = 1
@@ -197,7 +202,7 @@ class StartupPack(Message):
             self.clientUser, self.clientRcatZone = client_user
             self.relVersion = "rods{}.{}.{}".format(*IRODS_VERSION)
             self.apiVersion = "{3}".format(*IRODS_VERSION)
-            self.option = ""
+            self.option = application_name
 
     irodsProt = IntegerProperty()
     reconnFlag = IntegerProperty()
@@ -237,6 +242,18 @@ class BinBytesBuf(Message):
     buflen = IntegerProperty()
     buf = BinaryProperty()
 
+class BytesBuf(Message):
+    _name = 'BytesBuf_PI'
+    buflen = IntegerProperty()
+    buf = StringProperty()
+
+class JSONMessage(BytesBuf):
+    """A message body whose payload is just a BytesBuf containing JSON."""
+    def __init__(self, msg_struct):
+        """Initialize with a Python data structure that will be converted to JSON."""
+        s = json.dumps(msg_struct)
+        super(JSONMessage,self).__init__(buf=s,buflen=len(s))
+
 
 class PluginAuthMessage(Message):
     _name = 'authPlugReqInp_PI'
